==> deepin-camera_6.5.23.tar.xz: BUILD/src/translations/deepin-camera_sw.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="1181"/>
        <source>None</source>
        <translation>Hakuna</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1460"/>
        <source>Photo</source>
        <translation>Picha</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1469"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1901"/>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Umoshawishaji video uliopatikana. Uchafua kipengele?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="2034"/>
        <source>Switch Cameras</source>
        <translation>Tumia kamera mbili</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="2128"/>
        <source>Settings</source>
        <translation>Mipango</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../src/closedialog.cpp" line="26"/>
        <source>Cancel</source>
        <translation>Bali</translation>
    </message>
    <message>
        <location filename="../src/closedialog.cpp" line="26"/>
        <source>Close</source>
        <translation>Ondoa</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <location filename="../src/imageitem.cpp" line="66"/>
        <source>Copy</source>
        <translation>Kopia</translation>
    </message>
    <message>
        <location filename="../src/imageitem.cpp" line="70"/>
        <source>Delete</source>
        <translation>Ongeza</translation>
    </message>
    <message>
        <location filename="../src/imageitem.cpp" line="74"/>
        <source>Open folder</source>
        <translation>Ondoa kipengele</translation>
    </message>
    <message>
        <location filename="../src/imageitem.cpp" line="77"/>
        <source>Print</source>
        <translation>Miprinta</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="213"/>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="229"/>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera ni programu ya kusajiliwa picha na video kwa kuzingia kamera ya PC au webcam yako.</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="16"/>
        <source>OptionPicLineEditBtn</source>
        <translation>PichaLineEditBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="17"/>
        <source>OptionVideoLineEditBtn</source>
        <translation>VideoLineEditBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="18"/>
        <source>OptionFormatLabel</source>
        <translation>OptionFormatLabel</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="19"/>
        <source>OptionFrame</source>
        <translation>OptionFrame</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="20"/>
        <source>PicOption</source>
        <translation>PicOption</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="21"/>
        <source>VideoOption</source>
        <translation>VideoOption</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="22"/>
        <source>OptionPicSelectableLineEdit</source>
        <translation>OptionPicSelectableLineEdit</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="23"/>
        <source>OptionVideoSelectableLineEdit</source>
        <translation>OptionVideoSelectableLineEdit</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="24"/>
        <source>OptionInvalidDialog</source>
        <translation>OptionInvalidDialog</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="25"/>
        <source>SettingDialog</source>
        <translation>SettingDialog</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="27"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="28"/>
        <source>TitleBar</source>
        <translation>TitleBar</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="29"/>
        <source>TitleMenu</source>
        <translation>TitleMenu</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="30"/>
        <source>VideoPreviewWidget</source>
        <translation>VideoPreviewWidget</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="33"/>
        <source>SelectBtn</source>
        <translation>SelectBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="34"/>
        <source>PicVdBtn</source>
        <translation>PicVdBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="35"/>
        <source>TakeVdEndBtn</source>
        <translation>Tangia VdEndBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="36"/>
        <source>ThumbnailPreview</source>
        <translation>ThumbnailPreview</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="37"/>
        <source>ModeSwitchBox</source>
        <translation>ModeSwitchBox</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="38"/>
        <source>SwitchRecordBtn</source>
        <translation>SwitchRecordBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="40"/>
        <source>LeftBtnsBox</source>
        <translation>LeftBtnsBox</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="41"/>
        <source>UnfoldBtn</source>
        <translation>UnfoldBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="42"/>
        <source>FoldBtn</source>
        <translation>FoldBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="43"/>
        <source>FlashlightUnfoldBtn</source>
        <translation>FlashlightUnfoldBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="44"/>
        <source>FlashlightFoldBtn</source>
        <translation>FlashlightFoldBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="45"/>
        <source>FlashlightOnBtn</source>
        <translation>FlashlightOnBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="46"/>
        <source>FlashlightOffBtn</source>
        <translation>FlashlightOffBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="47"/>
        <source>DelayUnfoldBtn</source>
        <translation>DelayUnfoldBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="48"/>
        <source>DelayFoldBtn</source>
        <translation>DelayFoldBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="49"/>
        <source>DelayNoDelayBtn</source>
        <translation>DelayNoDelayBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="50"/>
        <source>Delay3SecBtn</source>
        <translation>Delay3SecBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="51"/>
        <source>Delay6SecBtn</source>
        <translation>Delay6SecBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="52"/>
        <source>FiltersUnfoldBtn</source>
        <translation>FiltersUnfoldBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="53"/>
        <source>FiltersFoldBtn</source>
        <translation>FiltersFoldBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="54"/>
        <source>FiltersCloseBtn</source>
        <translation>FiltersCloseBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="55"/>
        <source>ExposureBtn</source>
        <translation>ExposureBtn</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="56"/>
        <source>ExposureSlider</source>
        <translation>ExposureSlider</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="59"/>
        <source>ShortcutCallMenu</source>
        <translation>ShortcutCallMenu</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="60"/>
        <source>ShortcutCopy</source>
        <translation>ShortcutCopy</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="61"/>
        <source>ShortcutDelete</source>
        <translation>ShortcutDelete</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="62"/>
        <source>ShortcutOpenFolder</source>
        <translation>ShortcutOpenFolder</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="63"/>
        <source>ShortcutPrint</source>
        <translation>ShortcutPrint</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="66"/>
        <source>ViewShortCut</source>
        <translation>ViewShortCut</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="67"/>
        <source>SpaceShortCut</source>
        <translation>SpaceShortCut</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="70"/>
        <source>CloseDlg</source>
        <translation>CloseDlg</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="73"/>
        <source>PrintDialog</source>
        <translation>PrintDialog</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="76"/>
        <source>CancelBtn</source>
        <translation>Kubadili</translation>
    </message>
    <message>
        <location filename="../src/accessibility/ac-deepin-camera-define.h" line="77"/>
        <source>CloseBtn</source>
        <translation>Kubadili</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="287"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Saini sikuweza kufanya kazi katika kilele hili</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="289"/>
        <source>Close</source>
        <translation>Kubadili</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="361"/>
        <source>Open folder</source>
        <translation>Openda kilele</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="909"/>
        <source>File not saved</source>
        <translation>Faili haifanikiwa kushikiliza</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="10"/>
        <source>Settings</source>
        <translation>Mipango</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="11"/>
        <source>Basic</source>
        <translation>Mipango Moyo</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="12"/>
        <source>File location</source>
        <translation>Moyo ya faili</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="13"/>
        <source>Photos:</source>
        <translation>Poto:</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="14"/>
        <source>Videos:</source>
        <translation>Videot:</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="15"/>
        <source>Gridlines</source>
        <translation>Linu ya grid</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="16"/>
        <source>1*1 lines</source>
        <translation>Linu ya 1*1</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="17"/>
        <source>2*2 lines</source>
        <translation>Linu ya 2*2</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="18"/>
        <source>Shoot</source>
        <translation>Kufanya</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="19"/>
        <source>Burst mode</source>
        <translation>Mipango ya burst</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="20"/>
        <source>Self-timer delay</source>
        <translation>Mipango ya self-timer</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="21"/>
        <source>Mirror mode</source>
        <translation>Mipango ya mirror</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="22"/>
        <source>Flashlight</source>
        <translation>Flashlight</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="23"/>
        <source>Output</source>
        <translation>Kutumia</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="24"/>
        <source>Sound effects</source>
        <translation>Mipango ya suara</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="25"/>
        <source>Output format</source>
        <translation>Mipango ya kushikiliza</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="26"/>
        <source>Photo:</source>
        <translation>Poto:</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="27"/>
        <source>Video:</source>
        <translation>Videot:</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="28"/>
        <source>4 pcs</source>
        <translation>4 kiasi</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="29"/>
        <source>10 pcs</source>
        <translation>10 kiasi</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="30"/>
        <source>None</source>
        <translation>Hapana</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="31"/>
        <source>Resolution settings</source>
        <translation>Mipango ya resolution</translation>
    </message>
    <message>
        <location filename="../src/settings_translation.cpp" line="32"/>
        <source>Maximum resolution:</source>
        <translation>Resolution ya kubadilika:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../src/shortcut.cpp" line="14"/>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="15"/>
        <source>Settings</source>
        <translation>Mipasi</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="16"/>
        <source>Stop recording</source>
        <translation>Utengwa kucheza</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="17"/>
        <source>Stop taking photos</source>
        <translation>Utengwa kucheza vitu</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="18"/>
        <source>Context menu</source>
        <translation>Menu ya michezo</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="19"/>
        <source>Copy</source>
        <translation>Kopia</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="20"/>
        <source>Delete</source>
        <translation>Ondoa</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="21"/>
        <source>Open</source>
        <translation>Openda</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="22"/>
        <source>Print</source>
        <translation>Vipande</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="23"/>
        <source>Help</source>
        <translation>Mipasi</translation>
    </message>
    <message>
        <location filename="../src/shortcut.cpp" line="24"/>
        <source>Display shortcuts</source>
        <translation>Tazama michezo</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <location filename="../src/Settings.cpp" line="61"/>
        <source>mp4</source>
        <translation>mp4</translation>
    </message>
    <message>
        <location filename="../src/Settings.cpp" line="61"/>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <location filename="../src/Settings.cpp" line="191"/>
        <source>None</source>
        <translation>Hakuna</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="254"/>
        <source>Normal</source>
        <translation>Mafanikio</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="260"/>
        <source>Vivid</source>
        <translation>Mafanikio ya mazigo</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="263"/>
        <source>Warm</source>
        <translation>Mafanikio ya mafunzi</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="266"/>
        <source>Cold</source>
        <translation>Mafanikio ya mafunzi</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="269"/>
        <source>Retro</source>
        <translation>Mafanikio ya mazigo</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="272"/>
        <source>Film</source>
        <translation>Mafanikio ya mazigo</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="275"/>
        <source>Gray</source>
        <translation>Gray</translation>
    </message>
    <message>
        <location filename="../src/filterpreviewbutton.cpp" line="278"/>
        <source>B&amp;W</source>
        <translation>B&amp;W</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="83"/>
        <source>Flashlight</source>
        <translation>Flashlight</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="90"/>
        <source>On</source>
        <translation>Panga</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="97"/>
        <source>Off</source>
        <translation>Ofa</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="112"/>
        <source>Delay capture</source>
        <translation>Kucheza kwa kipengele</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="119"/>
        <source>None</source>
        <translation>Hakuna</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="142"/>
        <source>Filters</source>
        <translation>Michezo</translation>
    </message>
    <message>
        <location filename="../src/takephotosettingareawidget.cpp" line="191"/>
        <source>Exposure</source>
        <translation>Kuvunja</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <location filename="../src/videowidget.cpp" line="346"/>
        <source>No webcam found</source>
        <translation>Hakuna webcam inayotajwa</translation>
    </message>
    <message>
        <location filename="../src/videowidget.cpp" line="384"/>
        <source>The webcam is in use</source>
        <translation>Webcam inayotajwa inayotumika</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.28.tar.xz: BUILD/src/translations/deepin-camera_sw.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sw">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Video recording in progress. Close the window?</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Photo</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Switch Cameras</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Close</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Open folder</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Print</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Unaweza kufanya kazi na mfano hili</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Close</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Open folder</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Basic</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>File location</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Shoot</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Burst mode</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Self-timer delay</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Output</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Output format</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pcs</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pcs</translation>
    </message>
    <message>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>&gt;-
Camera ni programi ya kusajiliwa na video kwa kuzingatia kamera ya PC au
webcam.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>File not saved</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>&apos;Photo:&apos;</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Videoni:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Mipakaizi ya kipindani</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Picha:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Videoni:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Mipakaizi ya miziki</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Mipakaizi ya miru</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Mipakaizi ya mato</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Mipakaizi ya grid</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>Lini ya 1*1</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>Lini ya 2*2</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Kipakaizi ya kipindani kubwa:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Mipakaizi</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Zalisha video</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopia</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ondoa</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Kamenge</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Vipakaizi</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Mipakaizi</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Tazama mipakaizi</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Zalisha picha</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Menu ya kipakaizi</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Hakuna</translation>
    </message>
    <message>
        <source>mp4</source>
        <translation>mp4</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Kamili</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Mwimbi</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Mwimbi</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Mkali</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Mkali</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Filmi</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Mwenge</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>B&amp;W</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Mwaka</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Pamoja</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Pofu</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Unganisha kujitambua</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Hapana</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Mifoto</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Ukumbuka</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Hakuna webcam inayotajwa</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Webcam inayotajwa inaonyesha</translation>
    </message>
</context>
</TS>
